@@ -1,7 +1,7 @@
 package Dist::Zilla::Role::RequireFromBuild;
 
 our $DATE = '2017-01-09'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use Moose::Role;
@@ -44,7 +44,7 @@ Dist::Zilla::Role::RequireFromBuild - Role to require() from build files
 
 =head1 VERSION
 
-This document describes version 0.005 of Dist::Zilla::Role::RequireFromBuild (from Perl distribution Dist-Zilla-Role-RequireFromBuild), released on 2017-01-09.
+This document describes version 0.006 of Dist::Zilla::Role::RequireFromBuild (from Perl distribution Dist-Zilla-Role-RequireFromBuild), released on 2017-01-09.
 
 =head1 SYNOPSIS
 
@@ -102,7 +102,7 @@ feature.
 
 =head1 SEE ALSO
 
-L<lib::dzil::build>, the pragma version of the same functionality.
+L<Require::Hook::DzilBuild>
 
 =head1 AUTHOR
 
